@@ -1,10 +1,10 @@
-#    Copyright 2016 Alexey Stepanov aka penguinolog
+#    Copyright 2016-2022 Alexey Stepanov aka penguinolog
 #    Licensed under the Apache License, Version 2.0 (the "License"); you may
 #    not use this file except in compliance with the License. You may obtain
 #    a copy of the License at
-#
+
 #         http://www.apache.org/licenses/LICENSE-2.0
-#
+
 #    Unless required by applicable law or agreed to in writing, software
 #    distributed under the License is distributed on an "AS IS" BASIS, WITHOUT
 #    WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied. See the
@@ -13,6 +13,8 @@
 
 """Implement JSONField for SQLAlchemy."""
 
+from __future__ import annotations
+
 # Local Implementation
 from .jsonfield import JSONField
 from .jsonfield import mutable_json_field
